# Obsolescence Risk Management Dashboard
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-dashboard#overview)
  * [Inclusion of Fact Sheets for Calculation](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-dashboard#inclusion-of-fact-sheets-for-calculation)
  * [Configurability of Dashboard Panels](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-dashboard#configurability-of-dashboard-panels)
  * [Dashboard Panels](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-dashboard#dashboard-panels)


Obsolescence risk management dashboard helps monitor unaddressed and addressed obsolescence risks, along with data completeness for comprehensive risk management.
